@@ -453,10 +453,21 @@ class Client(object):
         if not repoll_max_cycles:
             repoll_max_cycles = self.STATUS_REPOLL_MAX_CYCLES
         story = self.story.story_post_file(file=file)
+        self.await_outline(story.id)
+        return self.story.story_id_get(story.id, include_outline=True, include_relationships=include_relationships)
+
+    def await_outline(self,
+                      story_id,
+                      status_repoll_seconds: int = None, 
+                      repoll_max_cycles: int = None):
         task_running = True
         repoll_cycle_count = 0
+        if not status_repoll_seconds:
+            status_repoll_seconds = self.STATUS_REPOLL_SECONDS
+        if not repoll_max_cycles:
+            repoll_max_cycles = self.STATUS_REPOLL_MAX_CYCLES
         while task_running:
-            status, status_code, _ = self.story.story_id_status_get_with_http_info(story.id)
+            status, status_code, _ = self.story.story_id_status_get_with_http_info(story_id)
             if status_code == 204:
                 task_running = False
             elif status_code == 200:
@@ -468,7 +479,9 @@ class Client(object):
                     logger.info("Story creation task still running.  Rechecking status in {0} seconds".format(status_repoll_seconds))
                     time.sleep(status_repoll_seconds)
                     repoll_cycle_count += 1
-        return self.story.story_id_get(story.id, include_outline=True, include_relationships=include_relationships)
+        return self.story.story_id_outline_get(story_id)
+
+
 
                 
         
@@ -483,6 +496,10 @@ class DocConverterApiClientWithAuth(presalytics.client.auth.AuthenticationMixIn,
         presalytics.client.presalytics_doc_converter.api_client.ApiClient.__init__(self)
         self.update_configuration()
 
+    @property
+    def api_name(self):
+        return 'doc-converter'
+
 
 class OoxmlAutomationApiClientWithAuth(presalytics.client.auth.AuthenticationMixIn, presalytics.client.presalytics_ooxml_automation.api_client.ApiClient):
     """
@@ -494,6 +511,10 @@ class OoxmlAutomationApiClientWithAuth(presalytics.client.auth.AuthenticationMix
         presalytics.client.presalytics_ooxml_automation.api_client.ApiClient.__init__(self)
         self.update_configuration()
 
+    @property
+    def api_name(self):
+        return 'ooxml-automation'
+
 
 class StoryApiClientWithAuth(presalytics.client.auth.AuthenticationMixIn, presalytics.client.presalytics_story.api_client.ApiClient):
     """
@@ -505,6 +526,10 @@ class StoryApiClientWithAuth(presalytics.client.auth.AuthenticationMixIn, presal
         presalytics.client.presalytics_story.api_client.ApiClient.__init__(self)
         self.update_configuration()
 
+    @property
+    def api_name(self):
+        return 'story'
+
 
 @functools.lru_cache(maxsize=None)
 def get_client():
